@@ -13,7 +13,7 @@ class LocalPlaybackProvider(base.BasePlaybackProvider):
     def change_track(self, track):
         media_dir = self.backend.config['local']['media_dir']
         # TODO: check that type is correct.
-        file_path = path.uri_to_path(track.uri).split(':', 1)[1]
+        file_path = path.uri_to_path(track.uri).split(b':', 1)[1]
         file_path = os.path.join(media_dir, file_path)
         track = track.copy(uri=path.path_to_uri(file_path))
         return super(LocalPlaybackProvider, self).change_track(track)
