@@ -66,15 +66,13 @@ class ImmutableObject(object):
         :type values: dict
         :rtype: new instance of the model being copied
         """
-        # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
-        # See https://github.com/mopidy/mopidy/issues/302 for details
         data = {}
         for key in self.__dict__.keys():
             public_key = key.lstrip('_')
-            data[str(public_key)] = values.pop(public_key, self.__dict__[key])
+            data[public_key] = values.pop(public_key, self.__dict__[key])
         for key in values.keys():
             if hasattr(self, key):
-                data[str(key)] = values.pop(key)
+                data[key] = values.pop(key)
         if values:
             raise TypeError(
                 'copy() got an unexpected keyword argument "%s"' % key)
@@ -92,7 +90,7 @@ class ImmutableObject(object):
                     for v in value]
             elif isinstance(value, ImmutableObject):
                 value = value.serialize()
-            if value:
+            if not (isinstance(value, list) and len(value) == 0):
                 data[public_key] = value
         return data
 
@@ -127,15 +125,13 @@ def model_json_decoder(dct):
         {u'a_track': Track(artists=[], name=u'name')}
 
     """
-    # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
-    # See https://github.com/mopidy/mopidy/issues/302 for details.
     if '__model__' in dct:
         model_name = dct.pop('__model__')
         cls = globals().get(model_name, None)
         if issubclass(cls, ImmutableObject):
             kwargs = {}
             for key, value in dct.items():
-                kwargs[str(key)] = value
+                kwargs[key] = value
             return cls(**kwargs)
     return dct
 
@@ -208,10 +204,8 @@ class Album(ImmutableObject):
     # actual usage of this field with more than one image.
 
     def __init__(self, *args, **kwargs):
-        # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
-        # See https://github.com/mopidy/mopidy/issues/302 for details
-        self.__dict__[b'artists'] = frozenset(kwargs.pop('artists', []))
-        self.__dict__[b'images'] = frozenset(kwargs.pop('images', []))
+        self.__dict__['artists'] = frozenset(kwargs.pop('artists', []))
+        self.__dict__['images'] = frozenset(kwargs.pop('images', []))
         super(Album, self).__init__(*args, **kwargs)
 
 
@@ -237,6 +231,8 @@ class Track(ImmutableObject):
     :type bitrate: integer
     :param musicbrainz_id: MusicBrainz ID
     :type musicbrainz_id: string
+    :param last_modified: Represents last modification time
+    :type last_modified: integer
     """
 
     #: The track URI. Read-only.
@@ -269,10 +265,13 @@ class Track(ImmutableObject):
     #: The MusicBrainz ID of the track. Read-only.
     musicbrainz_id = None
 
+    #: Integer representing when the track was last modified, exact meaning
+    #: depends on source of track. For local files this is the mtime, for other
+    #: backends it could be a timestamp or simply a version counter.
+    last_modified = 0
+
     def __init__(self, *args, **kwargs):
-        # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
-        # See https://github.com/mopidy/mopidy/issues/302 for details
-        self.__dict__[b'artists'] = frozenset(kwargs.pop('artists', []))
+        self.__dict__['artists'] = frozenset(kwargs.pop('artists', []))
         super(Track, self).__init__(*args, **kwargs)
 
 
@@ -304,11 +303,9 @@ class TlTrack(ImmutableObject):
     track = None
 
     def __init__(self, *args, **kwargs):
-        # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
-        # See https://github.com/mopidy/mopidy/issues/302 for details
         if len(args) == 2 and len(kwargs) == 0:
-            kwargs[b'tlid'] = args[0]
-            kwargs[b'track'] = args[1]
+            kwargs['tlid'] = args[0]
+            kwargs['track'] = args[1]
             args = []
         super(TlTrack, self).__init__(*args, **kwargs)
 
@@ -343,9 +340,7 @@ class Playlist(ImmutableObject):
     last_modified = None
 
     def __init__(self, *args, **kwargs):
-        # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
-        # See https://github.com/mopidy/mopidy/issues/302 for details
-        self.__dict__[b'tracks'] = tuple(kwargs.pop('tracks', []))
+        self.__dict__['tracks'] = tuple(kwargs.pop('tracks', []))
         super(Playlist, self).__init__(*args, **kwargs)
 
     # TODO: def insert(self, pos, track): ... ?
@@ -381,9 +376,7 @@ class SearchResult(ImmutableObject):
     albums = tuple()
 
     def __init__(self, *args, **kwargs):
-        # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
-        # See https://github.com/mopidy/mopidy/issues/302 for details
-        self.__dict__[b'tracks'] = tuple(kwargs.pop('tracks', []))
-        self.__dict__[b'artists'] = tuple(kwargs.pop('artists', []))
-        self.__dict__[b'albums'] = tuple(kwargs.pop('albums', []))
+        self.__dict__['tracks'] = tuple(kwargs.pop('tracks', []))
+        self.__dict__['artists'] = tuple(kwargs.pop('artists', []))
+        self.__dict__['albums'] = tuple(kwargs.pop('albums', []))
         super(SearchResult, self).__init__(*args, **kwargs)
