@@ -3,7 +3,6 @@ from __future__ import unicode_literals
 import functools
 import os
 import platform
-import sys
 
 import pygst
 pygst.require('0.10')
@@ -14,17 +13,6 @@ import pkg_resources
 from . import formatting
 
 
-def show_deps_optparse_callback(*args):
-    """
-    Prints a list of all dependencies.
-
-    Called by optparse when Mopidy is run with the :option:`--show-deps`
-    option.
-    """
-    print format_dependency_list()
-    sys.exit(0)
-
-
 def format_dependency_list(adapters=None):
     if adapters is None:
         dist_names = set([
