@@ -3,17 +3,19 @@ from __future__ import unicode_literals
 import os
 import subprocess
 import sys
+import unittest
 
 import mopidy
 
-from tests import unittest
-
 
 class HelpTest(unittest.TestCase):
     def test_help_has_mopidy_options(self):
         mopidy_dir = os.path.dirname(mopidy.__file__)
         args = [sys.executable, mopidy_dir, '--help']
-        process = subprocess.Popen(args, stdout=subprocess.PIPE)
+        process = subprocess.Popen(
+            args,
+            env={'PYTHONPATH': os.path.join(mopidy_dir, '..')},
+            stdout=subprocess.PIPE)
         output = process.communicate()[0]
         self.assertIn('--version', output)
         self.assertIn('--help', output)
